;; Generated package description from elfeed-web.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "elfeed-web" "3.4.2.0.20260519.210114" "Web interface to Elfeed" '((emacs "28.1") (compat "31") (elfeed "3.4.2") (simple-httpd "1.6")) :commit "48ff7b095dcc065ae937b3f364ef3edb6deee97a" :authors '(("Christopher Wellons" . "wellons@nullprogram.com")) :maintainer '(("Karthik Chikmagalur" . "karthik.chikmagalur@gmail.com") ("Ihor Radchenko" . "yantar92@posteo.net") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("network" "hypermedia") :url "https://github.com/emacs-elfeed/elfeed-web")
